#
# spec file for package whohas
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 8/2011 open-slx GmbH <Sascha.Manns@open-slx.de>
# Copyright (c) 2010 - 7/2011 Sascha Manns <saigkill@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           whohas
Version:        0.29.1
Release:        1.20
Summary:        Package list querying tool
License:        GPL-2.0-or-later
Group:          System/Console
Url:            http://www.philippwesche.org/200811/whohas/intro.html
Source0:        https://github.com/whohas/whohas/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/whohas/whohas/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source3:        whohas.keyring
# PATCH-FIX-OPENSUSE improve-fetchdoc.patch asterios.dramis@gmail.com -- Shift some of the burden in sub fetchdoc onto the LWP::UserAgent class. This also allows us to process XML files without breaking the first line
Patch0:         improve-fetchdoc.patch
# PATCH-FIX-UPSTREAM whohas-0.29.1-fix-permissions.patch -- Fix wrong executable bits set on docs 
Patch1:         whohas-0.29.1-fix-permissions.patch
# PATCH-FIX-UPSTREAM whohas-0.29.1-update-fedora.patch -- Update information for Fedora (picked from upstream)
Patch2:         whohas-0.29.1-update-fedora.patch
# PATCH-FIX-UPSTREAM whohas-0.29.1-update-openbsd.patch -- Update information for OpenBSD (picked from upstream)
Patch3:         whohas-0.29.1-update-openbsd.patch
Requires:       perl = %{perl_version}
Requires:       perl(LWP::UserAgent)
Requires:       perl(Thread::Queue)
Requires:       perl(forks)
Recommends:     perl(Sys::CPU)
BuildArch:      noarch

%description
whohas is a command line tool that allows querying several package lists at
once - currently supported are Arch, Debian, Fedora, Gentoo, Mandriva,
openSUSE, Slackware (and linuxpackages.net), Source Mage, Ubuntu, FreeBSD,
NetBSD, OpenBSD, Fink, MacPorts, Cygwin and OpenMoko. whohas is written in Perl
and was designed to help package maintainers find ebuilds, pkgbuilds and
similar package definitions from other distributions to learn from. However, it
can also be used by normal users who want to know:

 * Which distribution provides packages on which the user depends.
 * What version of a given package is in use in each distribution, or in each
   release of a distribution (not implemented for all distributions).

%prep
%autosetup -p1

%build
# Nothing to do.

%install
%make_install PREFIX=%{_prefix} docdir=%{_docdir}/%{name}

%files
%license LICENSE
%{_bindir}/%{name}
%{_docdir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%dir %{_mandir}/de/man1
%{_mandir}/de/man1/%{name}.1%{?ext_man}

%changelog
* Sun Jul  8 2018 antoine.belvire@opensuse.org
- Update to version 0.29.1:
  * Use less memory and improve threading (requires forks Perl
    module).
  * Update the documentation.
  * Fetch multiple suites at once for Debian/Ubuntu.
  * Improve options parsing.
  * Add a config file to set desired distros/releases.
  * Fix support for Gentoo, Slackware, OpenBSD, FreeBSD, Arch, AUR,
    Fedora, Fink, openSUSE, Mandriva and Cygwin.
- Add key to check signed tarball:
  * whohas.keyring (Paul Wise <pabs@debian.org>)
- Fix wrong permissions on installed files:
  * Add whohas-0.29.1-fix-permissions.patch.
- Rebase improve-fetchdoc.patch.
- Drop upstreamed patches:
  * archlinux-url-561536.patch
  * debian-versions.patch
  * dont-mask-vars-560891.patch
  * fedora-search-619873.patch
  * gentoo-result-url-516071.patch
  * help-param-513476.patch
  * manpage-0.23.patch
  * manpage-0.24.patch
  * openbsd-cache-results-557724.patch
  * opensuse.patch
  * strictness-510020-510524.patch
  * ubuntu-versions.patch
  * whohas-fix_install.patch
- Update information for OpenBSD and Fedora (picked from upstream):
  * Add whohas-0.29.1-update-fedora.patch.
  * Add whohas-0.29.1-update-openbsd.patch.
* Thu Nov 15 2012 asterios.dramis@gmail.com
- Replaced the following patches:
  * debian-versions-511364.patch with debian-versions.patch (updated the fix to
    correctly show all Debian versions - taken from Debian).
  * opensuse-searchpath-585596.patch with opensuse.patch (updated the fix to
    make it work with http://software.opensuse.org/search).
  * ubuntu-versions-510203.patch with ubuntu-versions.patch (updated the fix to
    correctly show all Ubuntu versions - taken from Debian).
- Updated the following patches (taken from Debian):
  * help-param-513476.patch (added patch description).
  * manpage-0.24.patch (added patch description).
  * strictness-510020-510524.patch (added patch description, update man pages).
- Renamed and Rebased the following patches (taken from Debian):
  * fedora-search-619873 with fedora-search-619873.patch
  * openbsd-cache-results-557724 with openbsd-cache-results-557724.patch
- Rebased the following patches (taken from Debian):
  * archlinux-url-561536.patch.
  * dont-mask-vars-560891.patch.
  * gentoo-result-url-516071.patch.
  * improve-fetchdoc.patch.
* Sat Feb  4 2012 asterios.dramis@gmail.com
- Rebased ubuntu-versions-510203.patch to apply cleanly.
- Removed opkg-repo.patch (repository doesn't respond).
- Readded openbsd-cache-results-557724.patch (problem not fixed upstream).
- Added fedora-search-619873.patch (taken from Debian) to support Fedora's
  package listing.
- Fix compilation in SLE (don't use make_install macro).
* Sun Dec  4 2011 asterios.dramis@gmail.com
- Update to version 0.29:
  * fixed AUR module
  * fixed Mandriva module
  * fixed a problem with openBSD URL construction
  * added new Slackware module to replace the previous one which queried a
    now-defunct (third party) web interface
  * code cleanup
  * implemented functionality suggested by Guillaume Delacour and Steve Cotton
  * updated to current version numbers of Ubuntu, Mandriva, openSUSE, OpenBSD,
    Fedora, Slackware (13.1 not 13.37 as we're waiting on linuxpackages.net to
    update their search interface)
- Rebased the following patches to apply cleanly:
  * manpage-0.24.patch.
  * debian-versions-511364.patch.
  * help-param-513476.patch.
  * strictness-510020-510524.patch.
  * improve-fetchdoc.patch.
  * opensuse-searchpath-585596.patch.
- Marked the following patches as PATCH-NEEDS-REBASE (not critical):
  * ubuntu-versions-510203.patch.
  * opkg-repo.patch.
- Removed the following patches:
  * use-getopt-513473.patch (merged upstream).
  * openbsd-cache-results.patch (fixed upstream).
  * fedora-version.patch (fixed upstream).
  * openbsd-url-586537.patch (fixed upstream).
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to GPL-2.0+ (SPDX style).
* Wed Aug 24 2011 Sascha.Manns@open-slx.de
- fixed build
* Sun Jul 24 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Removed find and perl-DateTime from Requires: (not needed).
  * Added perl-XML-Simple in Requires:.
  * Minor other updates.
- Added some patches (taken from Debian) that fix/improve various issues with
  the package and add support for more recent distributions.
- Removed whohas-opensuse-fix.patch and replaced it with the Debian patch which
  also shows the version number of a package.
* Sun Dec 26 2010 saigkill@opensuse.org
- prettyfied the spec file
* Tue Nov 16 2010 pth@suse.de
- Add a Makefile to do the install.
* Mon Nov 15 2010 saigkill@opensuse.org
- Updated patch. Thanks to Malcolm.
* Sun Nov 14 2010 saigkill@opensuse.org
- Removed the Patch, and added a new. This fixes both. The openSUSE
  Release is up to 11.3 and fixed the search URL.
* Sun Nov 14 2010 saigkill@opensuse.org
- added Patch that uses 11.3 instead of 11.2 as search term
* Sun Nov 14 2010 saigkill@opensuse.org
- removed finding binary and chmod
* Sun Nov 14 2010 saigkill@opensuse.org
- changed binary chmod from 744 to 644
* Sun Nov 14 2010 saigkill@opensuse.org
- ported whohas for openSUSE
- Initialversion 0.24
